declare module "windows.networking.backgroundtransfer" {
  export class BackgroundDownloadProgress {
    bytesReceived: Number;
    totalBytesToReceive: Number;
    status: BackgroundTransferStatus;
    hasResponseChanged: Boolean;
    hasRestarted: Boolean;
    constructor();
  }

  export class BackgroundUploadProgress {
    bytesReceived: Number;
    bytesSent: Number;
    totalBytesToReceive: Number;
    totalBytesToSend: Number;
    status: BackgroundTransferStatus;
    hasResponseChanged: Boolean;
    hasRestarted: Boolean;
    constructor();
  }

  export enum BackgroundTransferStatus {
    idle,
    running,
    pausedByApplication,
    pausedCostedNetwork,
    pausedNoNetwork,
    completed,
    canceled,
    error,
  }

  export enum BackgroundTransferCostPolicy {
    default,
    unrestrictedOnly,
    always,
  }

  export enum BackgroundTransferPriority {
    default,
    high,
  }

  export enum BackgroundTransferBehavior {
    parallel,
    serialized,
  }

  export class IBackgroundTransferBase {
    costPolicy: BackgroundTransferCostPolicy;
    group: String;
    method: String;
    proxyCredential: Object;
    serverCredential: Object;
    constructor();

    setRequestHeader(headerName: String, headerValue: String): void;

  }

  export class DownloadOperation {
    priority: BackgroundTransferPriority;
    progress: BackgroundDownloadProgress;
    resultFile: Object;
    costPolicy: BackgroundTransferCostPolicy;
    group: String;
    guid: String;
    method: String;
    requestedUri: Object;
    transferGroup: BackgroundTransferGroup;
    constructor();

    startAsync(callback: (error: Error, result: DownloadOperation) => void): void ;

    attachAsync(callback: (error: Error, result: DownloadOperation) => void): void ;

    pause(): void;

    resume(): void;

    getResultStreamAt(position: Number): Object;

    getResponseInformation(): ResponseInformation;

  }

  export class UnconstrainedTransferRequestResult {
    isUnconstrained: Boolean;
    constructor();

  }

  export class UploadOperation {
    progress: BackgroundUploadProgress;
    sourceFile: Object;
    costPolicy: BackgroundTransferCostPolicy;
    group: String;
    guid: String;
    method: String;
    requestedUri: Object;
    priority: BackgroundTransferPriority;
    transferGroup: BackgroundTransferGroup;
    constructor();

    startAsync(callback: (error: Error, result: UploadOperation) => void): void ;

    attachAsync(callback: (error: Error, result: UploadOperation) => void): void ;

    getResultStreamAt(position: Number): Object;

    getResponseInformation(): ResponseInformation;

  }

  export class BackgroundTransferGroup {
    transferBehavior: BackgroundTransferBehavior;
    name: String;
    constructor();

    static createGroup(name: String): BackgroundTransferGroup;


  }

  export class BackgroundTransferContentPart {
    constructor();
    constructor(name: String);
    constructor(name: String, fileName: String);

    setHeader(headerName: String, headerValue: String): void;

    setText(value: String): void;

    setFile(value: Object): void;

  }

  export class IBackgroundTransferOperation {
    costPolicy: BackgroundTransferCostPolicy;
    group: String;
    guid: String;
    method: String;
    requestedUri: Object;
    constructor();

    getResultStreamAt(position: Number): Object;

    getResponseInformation(): ResponseInformation;

  }

  export class ResponseInformation {
    actualUri: Object;
    headers: Object;
    isResumable: Boolean;
    statusCode: Number;
    constructor();

  }

  export class IBackgroundTransferOperationPriority {
    priority: BackgroundTransferPriority;
    constructor();

  }

  export class IBackgroundTransferContentPartFactory {
    constructor();

    createWithName(name: String): BackgroundTransferContentPart;

    createWithNameAndFileName(name: String, fileName: String): BackgroundTransferContentPart;

  }

  export class BackgroundDownloader {
    serverCredential: Object;
    proxyCredential: Object;
    method: String;
    group: String;
    costPolicy: BackgroundTransferCostPolicy;
    transferGroup: BackgroundTransferGroup;
    successToastNotification: Object;
    successTileNotification: Object;
    failureToastNotification: Object;
    failureTileNotification: Object;
    constructor();

    static getCurrentDownloadsForTransferGroupAsync(group: BackgroundTransferGroup, callback: (error: Error, result: Object) => void): void ;


    static requestUnconstrainedDownloadsAsync(operations: Object, callback: (error: Error, result: UnconstrainedTransferRequestResult) => void): void ;


    static getCurrentDownloadsAsync(callback: (error: Error, result: Object) => void): void ;
    static getCurrentDownloadsAsync(group: String, callback: (error: Error, result: Object) => void): void ;


    createDownloadAsync(uri: Object, resultFile: Object, requestBodyStream: Object, callback: (error: Error, result: DownloadOperation) => void): void ;

    createDownload(uri: Object, resultFile: Object): DownloadOperation;
    createDownload(uri: Object, resultFile: Object, requestBodyFile: Object): DownloadOperation;

    setRequestHeader(headerName: String, headerValue: String): void;

  }

  export class BackgroundUploader {
    serverCredential: Object;
    proxyCredential: Object;
    method: String;
    group: String;
    costPolicy: BackgroundTransferCostPolicy;
    transferGroup: BackgroundTransferGroup;
    successToastNotification: Object;
    successTileNotification: Object;
    failureToastNotification: Object;
    failureTileNotification: Object;
    constructor();

    static getCurrentUploadsForTransferGroupAsync(group: BackgroundTransferGroup, callback: (error: Error, result: Object) => void): void ;


    static requestUnconstrainedUploadsAsync(operations: Object, callback: (error: Error, result: UnconstrainedTransferRequestResult) => void): void ;


    static getCurrentUploadsAsync(callback: (error: Error, result: Object) => void): void ;
    static getCurrentUploadsAsync(group: String, callback: (error: Error, result: Object) => void): void ;


    createUploadFromStreamAsync(uri: Object, sourceStream: Object, callback: (error: Error, result: UploadOperation) => void): void ;

    createUploadAsync(uri: Object, parts: Object, callback: (error: Error, result: UploadOperation) => void): void ;
    createUploadAsync(uri: Object, parts: Object, subType: String, callback: (error: Error, result: UploadOperation) => void): void ;
    createUploadAsync(uri: Object, parts: Object, subType: String, boundary: String, callback: (error: Error, result: UploadOperation) => void): void ;

    createUpload(uri: Object, sourceFile: Object): UploadOperation;

    setRequestHeader(headerName: String, headerValue: String): void;

  }

  export class BackgroundTransferError {
    constructor();

    static getStatus(hresult: Number): Number;


  }

  export class ContentPrefetcher {
    static lastSuccessfulPrefetchTime: Date;
    static indirectContentUri: Object;
    static contentUris: Object;
    constructor();

  }

}



