// Copyright (c) Microsoft Corporation
// All rights reserved. 
//
// Licensed under the Apache License, Version 2.0 (the ""License""); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED ON AN  *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT. 
//
// See the Apache Version 2.0 License for specific language governing permissions and limitations under the License.

#define NTDDI_VERSION 0x06010000

#include <v8.h>
#include <string>
#include <node_object_wrap.h>
#include <ppltasks.h>
#include "CollectionsConverter.h"
#include "CollectionsWrap.h"
#include "node-async.h"
#include "NodeRtUtils.h"
#include "OpaqueWrapper.h"
#include "WrapperBase.h"

#using <Windows.WinMD>

// this undefs fixes the issues of compiling Windows.Data.Json, Windows.Storag.FileProperties, and Windows.Stroage.Search
// Some of the node header files brings windows definitions with the same names as some of the WinRT methods
#undef DocumentProperties
#undef GetObject
#undef CreateEvent
#undef FindText
#undef SendMessage

const char* REGISTRATION_TOKEN_MAP_PROPERTY_NAME = "__registrationTokenMap__";

using namespace v8;
using namespace node;
using namespace concurrency;

namespace NodeRT { namespace Windows { namespace Networking { namespace BackgroundTransfer { 
  v8::Handle<v8::Value> WrapIBackgroundTransferBase(::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^ UnwrapIBackgroundTransferBase(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapDownloadOperation(::Windows::Networking::BackgroundTransfer::DownloadOperation^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::DownloadOperation^ UnwrapDownloadOperation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapUnconstrainedTransferRequestResult(::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^ UnwrapUnconstrainedTransferRequestResult(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapUploadOperation(::Windows::Networking::BackgroundTransfer::UploadOperation^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::UploadOperation^ UnwrapUploadOperation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapBackgroundTransferGroup(::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ UnwrapBackgroundTransferGroup(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapBackgroundTransferContentPart(::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ UnwrapBackgroundTransferContentPart(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapIBackgroundTransferOperation(::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^ UnwrapIBackgroundTransferOperation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapResponseInformation(::Windows::Networking::BackgroundTransfer::ResponseInformation^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::ResponseInformation^ UnwrapResponseInformation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapIBackgroundTransferOperationPriority(::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^ UnwrapIBackgroundTransferOperationPriority(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapIBackgroundTransferContentPartFactory(::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^ UnwrapIBackgroundTransferContentPartFactory(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapBackgroundDownloader(::Windows::Networking::BackgroundTransfer::BackgroundDownloader^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::BackgroundDownloader^ UnwrapBackgroundDownloader(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapBackgroundUploader(::Windows::Networking::BackgroundTransfer::BackgroundUploader^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::BackgroundUploader^ UnwrapBackgroundUploader(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapBackgroundTransferError(::Windows::Networking::BackgroundTransfer::BackgroundTransferError^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::BackgroundTransferError^ UnwrapBackgroundTransferError(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapContentPrefetcher(::Windows::Networking::BackgroundTransfer::ContentPrefetcher^ wintRtInstance);
  ::Windows::Networking::BackgroundTransfer::ContentPrefetcher^ UnwrapContentPrefetcher(Handle<Value> value);
  


  static v8::Handle<v8::Value> InitBackgroundTransferStatusEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("BackgroundTransferStatus"), enumObject);

    enumObject->Set(String::NewSymbol("idle"), Integer::New(0));
    enumObject->Set(String::NewSymbol("running"), Integer::New(1));
    enumObject->Set(String::NewSymbol("pausedByApplication"), Integer::New(2));
    enumObject->Set(String::NewSymbol("pausedCostedNetwork"), Integer::New(3));
    enumObject->Set(String::NewSymbol("pausedNoNetwork"), Integer::New(4));
    enumObject->Set(String::NewSymbol("completed"), Integer::New(5));
    enumObject->Set(String::NewSymbol("canceled"), Integer::New(6));
    enumObject->Set(String::NewSymbol("error"), Integer::New(7));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitBackgroundTransferCostPolicyEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("BackgroundTransferCostPolicy"), enumObject);

    enumObject->Set(String::NewSymbol("default"), Integer::New(0));
    enumObject->Set(String::NewSymbol("unrestrictedOnly"), Integer::New(1));
    enumObject->Set(String::NewSymbol("always"), Integer::New(2));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitBackgroundTransferPriorityEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("BackgroundTransferPriority"), enumObject);

    enumObject->Set(String::NewSymbol("default"), Integer::New(0));
    enumObject->Set(String::NewSymbol("high"), Integer::New(1));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitBackgroundTransferBehaviorEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("BackgroundTransferBehavior"), enumObject);

    enumObject->Set(String::NewSymbol("parallel"), Integer::New(0));
    enumObject->Set(String::NewSymbol("serialized"), Integer::New(1));

    return scope.Close(Undefined());
  }



  
  static bool IsBackgroundDownloadProgressJsObject(Handle<Value> value)
  {
    if (!value->IsObject())
    {
      return false;
    }

    Handle<String> symbol;
    Handle<Object> obj = value.As<Object>();

    symbol = String::NewSymbol("bytesReceived");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsNumber())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("totalBytesToReceive");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsNumber())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("status");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsInt32())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("hasResponseChanged");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsBoolean())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("hasRestarted");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsBoolean())
      {
          return false;
      }
    }
    
    return true;
  }

  ::Windows::Networking::BackgroundTransfer::BackgroundDownloadProgress BackgroundDownloadProgressFromJsObject(Handle<Value> value)
  {
    HandleScope scope;
    ::Windows::Networking::BackgroundTransfer::BackgroundDownloadProgress returnValue;
    
    if (!value->IsObject())
    {
      ThrowException(Exception::TypeError(NodeRT::Utils::NewString(L"Unexpected type, expected an object")));
      return returnValue;
    }

    Handle<Object> obj = value.As<Object>();
    Handle<String> symbol;

    symbol = String::NewSymbol("bytesReceived");
    if (obj->Has(symbol))
    {
      returnValue.BytesReceived = static_cast<unsigned __int64>(obj->Get(symbol)->IntegerValue());
    }
    
    symbol = String::NewSymbol("totalBytesToReceive");
    if (obj->Has(symbol))
    {
      returnValue.TotalBytesToReceive = static_cast<unsigned __int64>(obj->Get(symbol)->IntegerValue());
    }
    
    symbol = String::NewSymbol("status");
    if (obj->Has(symbol))
    {
      returnValue.Status = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferStatus>(obj->Get(symbol)->Int32Value());
    }
    
    symbol = String::NewSymbol("hasResponseChanged");
    if (obj->Has(symbol))
    {
      returnValue.HasResponseChanged = obj->Get(symbol)->BooleanValue();
    }
    
    symbol = String::NewSymbol("hasRestarted");
    if (obj->Has(symbol))
    {
      returnValue.HasRestarted = obj->Get(symbol)->BooleanValue();
    }
    
    return returnValue;
  }

  Handle<Value> BackgroundDownloadProgressToJsObject(::Windows::Networking::BackgroundTransfer::BackgroundDownloadProgress value)
  {
    HandleScope scope;

    Handle<Object> obj = Object::New();

    obj->Set(String::NewSymbol("bytesReceived"), Number::New(static_cast<double>(value.BytesReceived)));
    obj->Set(String::NewSymbol("totalBytesToReceive"), Number::New(static_cast<double>(value.TotalBytesToReceive)));
    obj->Set(String::NewSymbol("status"), Integer::New(static_cast<int>(value.Status)));
    obj->Set(String::NewSymbol("hasResponseChanged"), Boolean::New(value.HasResponseChanged));
    obj->Set(String::NewSymbol("hasRestarted"), Boolean::New(value.HasRestarted));
    
    return scope.Close(obj);
  }

  
  static bool IsBackgroundUploadProgressJsObject(Handle<Value> value)
  {
    if (!value->IsObject())
    {
      return false;
    }

    Handle<String> symbol;
    Handle<Object> obj = value.As<Object>();

    symbol = String::NewSymbol("bytesReceived");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsNumber())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("bytesSent");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsNumber())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("totalBytesToReceive");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsNumber())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("totalBytesToSend");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsNumber())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("status");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsInt32())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("hasResponseChanged");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsBoolean())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("hasRestarted");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsBoolean())
      {
          return false;
      }
    }
    
    return true;
  }

  ::Windows::Networking::BackgroundTransfer::BackgroundUploadProgress BackgroundUploadProgressFromJsObject(Handle<Value> value)
  {
    HandleScope scope;
    ::Windows::Networking::BackgroundTransfer::BackgroundUploadProgress returnValue;
    
    if (!value->IsObject())
    {
      ThrowException(Exception::TypeError(NodeRT::Utils::NewString(L"Unexpected type, expected an object")));
      return returnValue;
    }

    Handle<Object> obj = value.As<Object>();
    Handle<String> symbol;

    symbol = String::NewSymbol("bytesReceived");
    if (obj->Has(symbol))
    {
      returnValue.BytesReceived = static_cast<unsigned __int64>(obj->Get(symbol)->IntegerValue());
    }
    
    symbol = String::NewSymbol("bytesSent");
    if (obj->Has(symbol))
    {
      returnValue.BytesSent = static_cast<unsigned __int64>(obj->Get(symbol)->IntegerValue());
    }
    
    symbol = String::NewSymbol("totalBytesToReceive");
    if (obj->Has(symbol))
    {
      returnValue.TotalBytesToReceive = static_cast<unsigned __int64>(obj->Get(symbol)->IntegerValue());
    }
    
    symbol = String::NewSymbol("totalBytesToSend");
    if (obj->Has(symbol))
    {
      returnValue.TotalBytesToSend = static_cast<unsigned __int64>(obj->Get(symbol)->IntegerValue());
    }
    
    symbol = String::NewSymbol("status");
    if (obj->Has(symbol))
    {
      returnValue.Status = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferStatus>(obj->Get(symbol)->Int32Value());
    }
    
    symbol = String::NewSymbol("hasResponseChanged");
    if (obj->Has(symbol))
    {
      returnValue.HasResponseChanged = obj->Get(symbol)->BooleanValue();
    }
    
    symbol = String::NewSymbol("hasRestarted");
    if (obj->Has(symbol))
    {
      returnValue.HasRestarted = obj->Get(symbol)->BooleanValue();
    }
    
    return returnValue;
  }

  Handle<Value> BackgroundUploadProgressToJsObject(::Windows::Networking::BackgroundTransfer::BackgroundUploadProgress value)
  {
    HandleScope scope;

    Handle<Object> obj = Object::New();

    obj->Set(String::NewSymbol("bytesReceived"), Number::New(static_cast<double>(value.BytesReceived)));
    obj->Set(String::NewSymbol("bytesSent"), Number::New(static_cast<double>(value.BytesSent)));
    obj->Set(String::NewSymbol("totalBytesToReceive"), Number::New(static_cast<double>(value.TotalBytesToReceive)));
    obj->Set(String::NewSymbol("totalBytesToSend"), Number::New(static_cast<double>(value.TotalBytesToSend)));
    obj->Set(String::NewSymbol("status"), Integer::New(static_cast<int>(value.Status)));
    obj->Set(String::NewSymbol("hasResponseChanged"), Boolean::New(value.HasResponseChanged));
    obj->Set(String::NewSymbol("hasRestarted"), Boolean::New(value.HasRestarted));
    
    return scope.Close(obj);
  }

  
  class IBackgroundTransferBase : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IBackgroundTransferBase"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setRequestHeader"), FunctionTemplate::New(SetRequestHeader)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("costPolicy"), CostPolicyGetter, CostPolicySetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("group"), GroupGetter, GroupSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("method"), MethodGetter, MethodSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("proxyCredential"), ProxyCredentialGetter, ProxyCredentialSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("serverCredential"), ServerCredentialGetter, ServerCredentialSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IBackgroundTransferBase"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IBackgroundTransferBase(::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IBackgroundTransferBase *wrapperInstance = new IBackgroundTransferBase(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> SetRequestHeader(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferBase *wrapper = IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->SetRequestHeader(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> CostPolicyGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferBase *wrapper = IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy result = wrapper->_instance->CostPolicy;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CostPolicySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(info.This()))
      {
        return;
      }

      IBackgroundTransferBase *wrapper = IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy winRtValue = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy>(value->Int32Value());

        wrapper->_instance->CostPolicy = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> GroupGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferBase *wrapper = IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Group;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void GroupSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(info.This()))
      {
        return;
      }

      IBackgroundTransferBase *wrapper = IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Group = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MethodGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferBase *wrapper = IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Method;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void MethodSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(info.This()))
      {
        return;
      }

      IBackgroundTransferBase *wrapper = IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Method = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ProxyCredentialGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferBase *wrapper = IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(info.This());

      try 
      {
        ::Windows::Security::Credentials::PasswordCredential^ result = wrapper->_instance->ProxyCredential;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Security.Credentials", "PasswordCredential", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ProxyCredentialSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Security::Credentials::PasswordCredential^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(info.This()))
      {
        return;
      }

      IBackgroundTransferBase *wrapper = IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(info.This());

      try 
      {
        
        ::Windows::Security::Credentials::PasswordCredential^ winRtValue = dynamic_cast<::Windows::Security::Credentials::PasswordCredential^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->ProxyCredential = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ServerCredentialGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferBase *wrapper = IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(info.This());

      try 
      {
        ::Windows::Security::Credentials::PasswordCredential^ result = wrapper->_instance->ServerCredential;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Security.Credentials", "PasswordCredential", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ServerCredentialSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Security::Credentials::PasswordCredential^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^>(info.This()))
      {
        return;
      }

      IBackgroundTransferBase *wrapper = IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(info.This());

      try 
      {
        
        ::Windows::Security::Credentials::PasswordCredential^ winRtValue = dynamic_cast<::Windows::Security::Credentials::PasswordCredential^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->ServerCredential = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIBackgroundTransferBase(::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^ UnwrapIBackgroundTransferBase(Handle<Value> value);
    friend bool IsIBackgroundTransferBaseWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IBackgroundTransferBase::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIBackgroundTransferBase(::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IBackgroundTransferBase::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::IBackgroundTransferBase^ UnwrapIBackgroundTransferBase(Handle<Value> value)
  {
     return IBackgroundTransferBase::Unwrap<IBackgroundTransferBase>(value.As<Object>())->_instance;
  }

  void InitIBackgroundTransferBase(Handle<Object> exports)
  {
    IBackgroundTransferBase::Init(exports);
  }

  class DownloadOperation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("DownloadOperation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("pause"), FunctionTemplate::New(Pause)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("resume"), FunctionTemplate::New(Resume)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResultStreamAt"), FunctionTemplate::New(GetResultStreamAt)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResponseInformation"), FunctionTemplate::New(GetResponseInformation)->GetFunction());
      
            
      func = FunctionTemplate::New(StartAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("startAsync"), func);
      func = FunctionTemplate::New(AttachAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("attachAsync"), func);
      
                  
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("priority"), PriorityGetter, PrioritySetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("progress"), ProgressGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("resultFile"), ResultFileGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("costPolicy"), CostPolicyGetter, CostPolicySetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("group"), GroupGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("guid"), GuidGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("method"), MethodGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("requestedUri"), RequestedUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("transferGroup"), TransferGroupGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("DownloadOperation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    DownloadOperation(::Windows::Networking::BackgroundTransfer::DownloadOperation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::DownloadOperation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::DownloadOperation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      DownloadOperation *wrapperInstance = new DownloadOperation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> StartAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(args.This());

      ::Windows::Foundation::IAsyncOperationWithProgress<::Windows::Networking::BackgroundTransfer::DownloadOperation^, ::Windows::Networking::BackgroundTransfer::DownloadOperation^>^ op;
    

      if (args.Length() == 1)
      {
        try
        {
          op = wrapper->_instance->StartAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::BackgroundTransfer::DownloadOperation^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapDownloadOperation(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> AttachAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(args.This());

      ::Windows::Foundation::IAsyncOperationWithProgress<::Windows::Networking::BackgroundTransfer::DownloadOperation^, ::Windows::Networking::BackgroundTransfer::DownloadOperation^>^ op;
    

      if (args.Length() == 1)
      {
        try
        {
          op = wrapper->_instance->AttachAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::BackgroundTransfer::DownloadOperation^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapDownloadOperation(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> Pause(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Pause();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Resume(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Resume();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetResultStreamAt(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(args.This());

      if (args.Length() == 1
        && args[0]->IsNumber())
      {
        try
        {
          unsigned __int64 arg0 = static_cast<unsigned __int64>(args[0]->IntegerValue());
          
          ::Windows::Storage::Streams::IInputStream^ result;
          result = wrapper->_instance->GetResultStreamAt(arg0);
          return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Storage.Streams", "IInputStream", result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetResponseInformation(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Networking::BackgroundTransfer::ResponseInformation^ result;
          result = wrapper->_instance->GetResponseInformation();
          return scope.Close(WrapResponseInformation(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> PriorityGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferPriority result = wrapper->_instance->Priority;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrioritySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(info.This()))
      {
        return;
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferPriority winRtValue = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferPriority>(value->Int32Value());

        wrapper->_instance->Priority = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ProgressGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundDownloadProgress result = wrapper->_instance->Progress;
        return scope.Close(BackgroundDownloadProgressToJsObject(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ResultFileGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(info.This());

      try 
      {
        ::Windows::Storage::IStorageFile^ result = wrapper->_instance->ResultFile;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Storage", "IStorageFile", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> CostPolicyGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy result = wrapper->_instance->CostPolicy;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CostPolicySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(info.This()))
      {
        return;
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy winRtValue = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy>(value->Int32Value());

        wrapper->_instance->CostPolicy = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> GroupGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Group;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> GuidGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(info.This());

      try 
      {
        ::Platform::Guid result = wrapper->_instance->Guid;
        return scope.Close(NodeRT::Utils::GuidToJs(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MethodGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Method;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RequestedUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(info.This());

      try 
      {
        ::Windows::Foundation::Uri^ result = wrapper->_instance->RequestedUri;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "Uri", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TransferGroupGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DownloadOperation *wrapper = DownloadOperation::Unwrap<DownloadOperation>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ result = wrapper->_instance->TransferGroup;
        return scope.Close(WrapBackgroundTransferGroup(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::BackgroundTransfer::DownloadOperation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapDownloadOperation(::Windows::Networking::BackgroundTransfer::DownloadOperation^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::DownloadOperation^ UnwrapDownloadOperation(Handle<Value> value);
    friend bool IsDownloadOperationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> DownloadOperation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapDownloadOperation(::Windows::Networking::BackgroundTransfer::DownloadOperation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(DownloadOperation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::DownloadOperation^ UnwrapDownloadOperation(Handle<Value> value)
  {
     return DownloadOperation::Unwrap<DownloadOperation>(value.As<Object>())->_instance;
  }

  void InitDownloadOperation(Handle<Object> exports)
  {
    DownloadOperation::Init(exports);
  }

  class UnconstrainedTransferRequestResult : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("UnconstrainedTransferRequestResult"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("isUnconstrained"), IsUnconstrainedGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("UnconstrainedTransferRequestResult"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    UnconstrainedTransferRequestResult(::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      UnconstrainedTransferRequestResult *wrapperInstance = new UnconstrainedTransferRequestResult(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> IsUnconstrainedGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UnconstrainedTransferRequestResult *wrapper = UnconstrainedTransferRequestResult::Unwrap<UnconstrainedTransferRequestResult>(info.This());

      try 
      {
        bool result = wrapper->_instance->IsUnconstrained;
        return scope.Close(Boolean::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapUnconstrainedTransferRequestResult(::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^ UnwrapUnconstrainedTransferRequestResult(Handle<Value> value);
    friend bool IsUnconstrainedTransferRequestResultWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> UnconstrainedTransferRequestResult::s_constructorTemplate;

  v8::Handle<v8::Value> WrapUnconstrainedTransferRequestResult(::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(UnconstrainedTransferRequestResult::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^ UnwrapUnconstrainedTransferRequestResult(Handle<Value> value)
  {
     return UnconstrainedTransferRequestResult::Unwrap<UnconstrainedTransferRequestResult>(value.As<Object>())->_instance;
  }

  void InitUnconstrainedTransferRequestResult(Handle<Object> exports)
  {
    UnconstrainedTransferRequestResult::Init(exports);
  }

  class UploadOperation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("UploadOperation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResultStreamAt"), FunctionTemplate::New(GetResultStreamAt)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResponseInformation"), FunctionTemplate::New(GetResponseInformation)->GetFunction());
      
            
      func = FunctionTemplate::New(StartAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("startAsync"), func);
      func = FunctionTemplate::New(AttachAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("attachAsync"), func);
      
                  
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("progress"), ProgressGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("sourceFile"), SourceFileGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("costPolicy"), CostPolicyGetter, CostPolicySetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("group"), GroupGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("guid"), GuidGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("method"), MethodGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("requestedUri"), RequestedUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("priority"), PriorityGetter, PrioritySetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("transferGroup"), TransferGroupGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("UploadOperation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    UploadOperation(::Windows::Networking::BackgroundTransfer::UploadOperation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::UploadOperation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::UploadOperation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      UploadOperation *wrapperInstance = new UploadOperation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> StartAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(args.This());

      ::Windows::Foundation::IAsyncOperationWithProgress<::Windows::Networking::BackgroundTransfer::UploadOperation^, ::Windows::Networking::BackgroundTransfer::UploadOperation^>^ op;
    

      if (args.Length() == 1)
      {
        try
        {
          op = wrapper->_instance->StartAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::BackgroundTransfer::UploadOperation^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapUploadOperation(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> AttachAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(args.This());

      ::Windows::Foundation::IAsyncOperationWithProgress<::Windows::Networking::BackgroundTransfer::UploadOperation^, ::Windows::Networking::BackgroundTransfer::UploadOperation^>^ op;
    

      if (args.Length() == 1)
      {
        try
        {
          op = wrapper->_instance->AttachAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::BackgroundTransfer::UploadOperation^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapUploadOperation(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> GetResultStreamAt(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(args.This());

      if (args.Length() == 1
        && args[0]->IsNumber())
      {
        try
        {
          unsigned __int64 arg0 = static_cast<unsigned __int64>(args[0]->IntegerValue());
          
          ::Windows::Storage::Streams::IInputStream^ result;
          result = wrapper->_instance->GetResultStreamAt(arg0);
          return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Storage.Streams", "IInputStream", result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetResponseInformation(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Networking::BackgroundTransfer::ResponseInformation^ result;
          result = wrapper->_instance->GetResponseInformation();
          return scope.Close(WrapResponseInformation(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> ProgressGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundUploadProgress result = wrapper->_instance->Progress;
        return scope.Close(BackgroundUploadProgressToJsObject(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> SourceFileGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(info.This());

      try 
      {
        ::Windows::Storage::IStorageFile^ result = wrapper->_instance->SourceFile;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Storage", "IStorageFile", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> CostPolicyGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy result = wrapper->_instance->CostPolicy;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CostPolicySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(info.This()))
      {
        return;
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy winRtValue = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy>(value->Int32Value());

        wrapper->_instance->CostPolicy = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> GroupGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Group;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> GuidGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(info.This());

      try 
      {
        ::Platform::Guid result = wrapper->_instance->Guid;
        return scope.Close(NodeRT::Utils::GuidToJs(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MethodGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Method;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RequestedUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(info.This());

      try 
      {
        ::Windows::Foundation::Uri^ result = wrapper->_instance->RequestedUri;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "Uri", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PriorityGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferPriority result = wrapper->_instance->Priority;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrioritySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(info.This()))
      {
        return;
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferPriority winRtValue = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferPriority>(value->Int32Value());

        wrapper->_instance->Priority = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> TransferGroupGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      UploadOperation *wrapper = UploadOperation::Unwrap<UploadOperation>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ result = wrapper->_instance->TransferGroup;
        return scope.Close(WrapBackgroundTransferGroup(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::BackgroundTransfer::UploadOperation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapUploadOperation(::Windows::Networking::BackgroundTransfer::UploadOperation^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::UploadOperation^ UnwrapUploadOperation(Handle<Value> value);
    friend bool IsUploadOperationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> UploadOperation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapUploadOperation(::Windows::Networking::BackgroundTransfer::UploadOperation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(UploadOperation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::UploadOperation^ UnwrapUploadOperation(Handle<Value> value)
  {
     return UploadOperation::Unwrap<UploadOperation>(value.As<Object>())->_instance;
  }

  void InitUploadOperation(Handle<Object> exports)
  {
    UploadOperation::Init(exports);
  }

  class BackgroundTransferGroup : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("BackgroundTransferGroup"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("transferBehavior"), TransferBehaviorGetter, TransferBehaviorSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("name"), NameGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("createGroup"), FunctionTemplate::New(CreateGroup)->GetFunction());

      exports->Set(String::NewSymbol("BackgroundTransferGroup"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    BackgroundTransferGroup(::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      BackgroundTransferGroup *wrapperInstance = new BackgroundTransferGroup(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  


    static Handle<Value> CreateGroup(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ result;
          result = ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup::CreateGroup(arg0);
          return scope.Close(WrapBackgroundTransferGroup(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> TransferBehaviorGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundTransferGroup *wrapper = BackgroundTransferGroup::Unwrap<BackgroundTransferGroup>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferBehavior result = wrapper->_instance->TransferBehavior;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void TransferBehaviorSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^>(info.This()))
      {
        return;
      }

      BackgroundTransferGroup *wrapper = BackgroundTransferGroup::Unwrap<BackgroundTransferGroup>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferBehavior winRtValue = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferBehavior>(value->Int32Value());

        wrapper->_instance->TransferBehavior = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundTransferGroup *wrapper = BackgroundTransferGroup::Unwrap<BackgroundTransferGroup>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Name;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapBackgroundTransferGroup(::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ UnwrapBackgroundTransferGroup(Handle<Value> value);
    friend bool IsBackgroundTransferGroupWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> BackgroundTransferGroup::s_constructorTemplate;

  v8::Handle<v8::Value> WrapBackgroundTransferGroup(::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(BackgroundTransferGroup::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ UnwrapBackgroundTransferGroup(Handle<Value> value)
  {
     return BackgroundTransferGroup::Unwrap<BackgroundTransferGroup>(value.As<Object>())->_instance;
  }

  void InitBackgroundTransferGroup(Handle<Object> exports)
  {
    BackgroundTransferGroup::Init(exports);
  }

  class BackgroundTransferContentPart : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("BackgroundTransferContentPart"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setHeader"), FunctionTemplate::New(SetHeader)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setText"), FunctionTemplate::New(SetText)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setFile"), FunctionTemplate::New(SetFile)->GetFunction());
      
                        
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("BackgroundTransferContentPart"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    BackgroundTransferContentPart(::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          winRtInstance = ref new ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          winRtInstance = ref new ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart(arg0,arg1);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      BackgroundTransferContentPart *wrapperInstance = new BackgroundTransferContentPart(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> SetHeader(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundTransferContentPart *wrapper = BackgroundTransferContentPart::Unwrap<BackgroundTransferContentPart>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->SetHeader(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetText(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundTransferContentPart *wrapper = BackgroundTransferContentPart::Unwrap<BackgroundTransferContentPart>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          wrapper->_instance->SetText(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetFile(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundTransferContentPart *wrapper = BackgroundTransferContentPart::Unwrap<BackgroundTransferContentPart>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::IStorageFile^>(args[0]))
      {
        try
        {
          ::Windows::Storage::IStorageFile^ arg0 = dynamic_cast<::Windows::Storage::IStorageFile^>(NodeRT::Utils::GetObjectInstance(args[0]));
          
          wrapper->_instance->SetFile(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }





  private:
    ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapBackgroundTransferContentPart(::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ UnwrapBackgroundTransferContentPart(Handle<Value> value);
    friend bool IsBackgroundTransferContentPartWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> BackgroundTransferContentPart::s_constructorTemplate;

  v8::Handle<v8::Value> WrapBackgroundTransferContentPart(::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(BackgroundTransferContentPart::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ UnwrapBackgroundTransferContentPart(Handle<Value> value)
  {
     return BackgroundTransferContentPart::Unwrap<BackgroundTransferContentPart>(value.As<Object>())->_instance;
  }

  void InitBackgroundTransferContentPart(Handle<Object> exports)
  {
    BackgroundTransferContentPart::Init(exports);
  }

  class IBackgroundTransferOperation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IBackgroundTransferOperation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResultStreamAt"), FunctionTemplate::New(GetResultStreamAt)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResponseInformation"), FunctionTemplate::New(GetResponseInformation)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("costPolicy"), CostPolicyGetter, CostPolicySetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("group"), GroupGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("guid"), GuidGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("method"), MethodGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("requestedUri"), RequestedUriGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IBackgroundTransferOperation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IBackgroundTransferOperation(::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IBackgroundTransferOperation *wrapperInstance = new IBackgroundTransferOperation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetResultStreamAt(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferOperation *wrapper = IBackgroundTransferOperation::Unwrap<IBackgroundTransferOperation>(args.This());

      if (args.Length() == 1
        && args[0]->IsNumber())
      {
        try
        {
          unsigned __int64 arg0 = static_cast<unsigned __int64>(args[0]->IntegerValue());
          
          ::Windows::Storage::Streams::IInputStream^ result;
          result = wrapper->_instance->GetResultStreamAt(arg0);
          return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Storage.Streams", "IInputStream", result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetResponseInformation(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferOperation *wrapper = IBackgroundTransferOperation::Unwrap<IBackgroundTransferOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Networking::BackgroundTransfer::ResponseInformation^ result;
          result = wrapper->_instance->GetResponseInformation();
          return scope.Close(WrapResponseInformation(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> CostPolicyGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferOperation *wrapper = IBackgroundTransferOperation::Unwrap<IBackgroundTransferOperation>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy result = wrapper->_instance->CostPolicy;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CostPolicySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^>(info.This()))
      {
        return;
      }

      IBackgroundTransferOperation *wrapper = IBackgroundTransferOperation::Unwrap<IBackgroundTransferOperation>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy winRtValue = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy>(value->Int32Value());

        wrapper->_instance->CostPolicy = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> GroupGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferOperation *wrapper = IBackgroundTransferOperation::Unwrap<IBackgroundTransferOperation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Group;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> GuidGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferOperation *wrapper = IBackgroundTransferOperation::Unwrap<IBackgroundTransferOperation>(info.This());

      try 
      {
        ::Platform::Guid result = wrapper->_instance->Guid;
        return scope.Close(NodeRT::Utils::GuidToJs(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MethodGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferOperation *wrapper = IBackgroundTransferOperation::Unwrap<IBackgroundTransferOperation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Method;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> RequestedUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferOperation *wrapper = IBackgroundTransferOperation::Unwrap<IBackgroundTransferOperation>(info.This());

      try 
      {
        ::Windows::Foundation::Uri^ result = wrapper->_instance->RequestedUri;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "Uri", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIBackgroundTransferOperation(::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^ UnwrapIBackgroundTransferOperation(Handle<Value> value);
    friend bool IsIBackgroundTransferOperationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IBackgroundTransferOperation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIBackgroundTransferOperation(::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IBackgroundTransferOperation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperation^ UnwrapIBackgroundTransferOperation(Handle<Value> value)
  {
     return IBackgroundTransferOperation::Unwrap<IBackgroundTransferOperation>(value.As<Object>())->_instance;
  }

  void InitIBackgroundTransferOperation(Handle<Object> exports)
  {
    IBackgroundTransferOperation::Init(exports);
  }

  class ResponseInformation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ResponseInformation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("actualUri"), ActualUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("headers"), HeadersGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("isResumable"), IsResumableGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("statusCode"), StatusCodeGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ResponseInformation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ResponseInformation(::Windows::Networking::BackgroundTransfer::ResponseInformation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::ResponseInformation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::ResponseInformation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::ResponseInformation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ResponseInformation *wrapperInstance = new ResponseInformation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> ActualUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::ResponseInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ResponseInformation *wrapper = ResponseInformation::Unwrap<ResponseInformation>(info.This());

      try 
      {
        ::Windows::Foundation::Uri^ result = wrapper->_instance->ActualUri;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "Uri", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> HeadersGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::ResponseInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ResponseInformation *wrapper = ResponseInformation::Unwrap<ResponseInformation>(info.This());

      try 
      {
        ::Windows::Foundation::Collections::IMapView<::Platform::String^, ::Platform::String^>^ result = wrapper->_instance->Headers;
        return scope.Close(NodeRT::Collections::MapViewWrapper<::Platform::String^,::Platform::String^>::CreateMapViewWrapper(result, 
            [](::Platform::String^ val) -> Handle<Value> {
              return NodeRT::Utils::NewString(val->Data());
            },
            [](Handle<Value> value) -> bool {
              return value->IsString();
            },
            [](Handle<Value> value) -> ::Platform::String^ {
              return ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));
            },
            [](::Platform::String^ val) -> Handle<Value> {
              return NodeRT::Utils::NewString(val->Data());
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> IsResumableGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::ResponseInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ResponseInformation *wrapper = ResponseInformation::Unwrap<ResponseInformation>(info.This());

      try 
      {
        bool result = wrapper->_instance->IsResumable;
        return scope.Close(Boolean::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> StatusCodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::ResponseInformation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ResponseInformation *wrapper = ResponseInformation::Unwrap<ResponseInformation>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->StatusCode;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Networking::BackgroundTransfer::ResponseInformation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapResponseInformation(::Windows::Networking::BackgroundTransfer::ResponseInformation^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::ResponseInformation^ UnwrapResponseInformation(Handle<Value> value);
    friend bool IsResponseInformationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ResponseInformation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapResponseInformation(::Windows::Networking::BackgroundTransfer::ResponseInformation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ResponseInformation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::ResponseInformation^ UnwrapResponseInformation(Handle<Value> value)
  {
     return ResponseInformation::Unwrap<ResponseInformation>(value.As<Object>())->_instance;
  }

  void InitResponseInformation(Handle<Object> exports)
  {
    ResponseInformation::Init(exports);
  }

  class IBackgroundTransferOperationPriority : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IBackgroundTransferOperationPriority"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("priority"), PriorityGetter, PrioritySetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IBackgroundTransferOperationPriority"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IBackgroundTransferOperationPriority(::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IBackgroundTransferOperationPriority *wrapperInstance = new IBackgroundTransferOperationPriority(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> PriorityGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferOperationPriority *wrapper = IBackgroundTransferOperationPriority::Unwrap<IBackgroundTransferOperationPriority>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferPriority result = wrapper->_instance->Priority;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrioritySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^>(info.This()))
      {
        return;
      }

      IBackgroundTransferOperationPriority *wrapper = IBackgroundTransferOperationPriority::Unwrap<IBackgroundTransferOperationPriority>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferPriority winRtValue = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferPriority>(value->Int32Value());

        wrapper->_instance->Priority = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIBackgroundTransferOperationPriority(::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^ UnwrapIBackgroundTransferOperationPriority(Handle<Value> value);
    friend bool IsIBackgroundTransferOperationPriorityWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IBackgroundTransferOperationPriority::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIBackgroundTransferOperationPriority(::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IBackgroundTransferOperationPriority::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::IBackgroundTransferOperationPriority^ UnwrapIBackgroundTransferOperationPriority(Handle<Value> value)
  {
     return IBackgroundTransferOperationPriority::Unwrap<IBackgroundTransferOperationPriority>(value.As<Object>())->_instance;
  }

  void InitIBackgroundTransferOperationPriority(Handle<Object> exports)
  {
    IBackgroundTransferOperationPriority::Init(exports);
  }

  class IBackgroundTransferContentPartFactory : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IBackgroundTransferContentPartFactory"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createWithName"), FunctionTemplate::New(CreateWithName)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createWithNameAndFileName"), FunctionTemplate::New(CreateWithNameAndFileName)->GetFunction());
      
                        
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IBackgroundTransferContentPartFactory"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IBackgroundTransferContentPartFactory(::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IBackgroundTransferContentPartFactory *wrapperInstance = new IBackgroundTransferContentPartFactory(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> CreateWithName(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferContentPartFactory *wrapper = IBackgroundTransferContentPartFactory::Unwrap<IBackgroundTransferContentPartFactory>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ result;
          result = wrapper->_instance->CreateWithName(arg0);
          return scope.Close(WrapBackgroundTransferContentPart(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateWithNameAndFileName(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IBackgroundTransferContentPartFactory *wrapper = IBackgroundTransferContentPartFactory::Unwrap<IBackgroundTransferContentPartFactory>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ result;
          result = wrapper->_instance->CreateWithNameAndFileName(arg0, arg1);
          return scope.Close(WrapBackgroundTransferContentPart(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }





  private:
    ::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIBackgroundTransferContentPartFactory(::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^ UnwrapIBackgroundTransferContentPartFactory(Handle<Value> value);
    friend bool IsIBackgroundTransferContentPartFactoryWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IBackgroundTransferContentPartFactory::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIBackgroundTransferContentPartFactory(::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IBackgroundTransferContentPartFactory::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::IBackgroundTransferContentPartFactory^ UnwrapIBackgroundTransferContentPartFactory(Handle<Value> value)
  {
     return IBackgroundTransferContentPartFactory::Unwrap<IBackgroundTransferContentPartFactory>(value.As<Object>())->_instance;
  }

  void InitIBackgroundTransferContentPartFactory(Handle<Object> exports)
  {
    IBackgroundTransferContentPartFactory::Init(exports);
  }

  class BackgroundDownloader : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("BackgroundDownloader"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createDownload"), FunctionTemplate::New(CreateDownload)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setRequestHeader"), FunctionTemplate::New(SetRequestHeader)->GetFunction());
      
            
      func = FunctionTemplate::New(CreateDownloadAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createDownloadAsync"), func);
      
                  
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("serverCredential"), ServerCredentialGetter, ServerCredentialSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("proxyCredential"), ProxyCredentialGetter, ProxyCredentialSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("method"), MethodGetter, MethodSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("group"), GroupGetter, GroupSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("costPolicy"), CostPolicyGetter, CostPolicySetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("transferGroup"), TransferGroupGetter, TransferGroupSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("successToastNotification"), SuccessToastNotificationGetter, SuccessToastNotificationSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("successTileNotification"), SuccessTileNotificationGetter, SuccessTileNotificationSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("failureToastNotification"), FailureToastNotificationGetter, FailureToastNotificationSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("failureTileNotification"), FailureTileNotificationGetter, FailureTileNotificationSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      func = FunctionTemplate::New(GetCurrentDownloadsForTransferGroupAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      constructor->Set(String::NewSymbol("getCurrentDownloadsForTransferGroupAsync"), func);
      func = FunctionTemplate::New(RequestUnconstrainedDownloadsAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      constructor->Set(String::NewSymbol("requestUnconstrainedDownloadsAsync"), func);
      func = FunctionTemplate::New(GetCurrentDownloadsAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      constructor->Set(String::NewSymbol("getCurrentDownloadsAsync"), func);

      exports->Set(String::NewSymbol("BackgroundDownloader"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    BackgroundDownloader(::Windows::Networking::BackgroundTransfer::BackgroundDownloader^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::BackgroundDownloader^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::BackgroundDownloader^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::Networking::BackgroundTransfer::BackgroundDownloader();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      BackgroundDownloader *wrapperInstance = new BackgroundDownloader(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> CreateDownloadAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Networking::BackgroundTransfer::DownloadOperation^>^ op;
    

      if (args.Length() == 4
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::IStorageFile^>(args[1])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::Streams::IInputStream^>(args[2]))
      {
        try
        {
          ::Windows::Foundation::Uri^ arg0 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[0]));
          ::Windows::Storage::IStorageFile^ arg1 = dynamic_cast<::Windows::Storage::IStorageFile^>(NodeRT::Utils::GetObjectInstance(args[1]));
          ::Windows::Storage::Streams::IInputStream^ arg2 = dynamic_cast<::Windows::Storage::Streams::IInputStream^>(NodeRT::Utils::GetObjectInstance(args[2]));
          
          op = wrapper->_instance->CreateDownloadAsync(arg0,arg1,arg2);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::BackgroundTransfer::DownloadOperation^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapDownloadOperation(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> CreateDownload(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::IStorageFile^>(args[1]))
      {
        try
        {
          ::Windows::Foundation::Uri^ arg0 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[0]));
          ::Windows::Storage::IStorageFile^ arg1 = dynamic_cast<::Windows::Storage::IStorageFile^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Networking::BackgroundTransfer::DownloadOperation^ result;
          result = wrapper->_instance->CreateDownload(arg0, arg1);
          return scope.Close(WrapDownloadOperation(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 3
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::IStorageFile^>(args[1])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::IStorageFile^>(args[2]))
      {
        try
        {
          ::Windows::Foundation::Uri^ arg0 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[0]));
          ::Windows::Storage::IStorageFile^ arg1 = dynamic_cast<::Windows::Storage::IStorageFile^>(NodeRT::Utils::GetObjectInstance(args[1]));
          ::Windows::Storage::IStorageFile^ arg2 = dynamic_cast<::Windows::Storage::IStorageFile^>(NodeRT::Utils::GetObjectInstance(args[2]));
          
          ::Windows::Networking::BackgroundTransfer::DownloadOperation^ result;
          result = wrapper->_instance->CreateDownload(arg0, arg1, arg2);
          return scope.Close(WrapDownloadOperation(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetRequestHeader(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->SetRequestHeader(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> GetCurrentDownloadsForTransferGroupAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ::Windows::Foundation::IAsyncOperation<::Windows::Foundation::Collections::IVectorView<::Windows::Networking::BackgroundTransfer::DownloadOperation^>^>^ op;
      

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^>(args[0]))
      {
        try
        {
          ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ arg0 = UnwrapBackgroundTransferGroup(args[0]);
          
          op = ::Windows::Networking::BackgroundTransfer::BackgroundDownloader::GetCurrentDownloadsForTransferGroupAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Foundation::Collections::IVectorView<::Windows::Networking::BackgroundTransfer::DownloadOperation^>^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {

            
            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = NodeRT::Collections::VectorViewWrapper<::Windows::Networking::BackgroundTransfer::DownloadOperation^>::CreateVectorViewWrapper(result, 
            [](::Windows::Networking::BackgroundTransfer::DownloadOperation^ val) -> Handle<Value> {
              return WrapDownloadOperation(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Networking::BackgroundTransfer::DownloadOperation^ {
              return UnwrapDownloadOperation(value);
            }
          );
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
          
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> RequestUnconstrainedDownloadsAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ::Windows::Foundation::IAsyncOperation<::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^>^ op;
      

      if (args.Length() == 2
        && (NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::DownloadOperation^>^>(args[0]) || args[0]->IsArray()))
      {
        try
        {
          ::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::DownloadOperation^>^ arg0 = 
            [] (v8::Handle<v8::Value> value) -> ::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::DownloadOperation^>^
            {
              if (value->IsArray())
              {
                return NodeRT::Collections::JsArrayToWinrtVector<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(value.As<Array>(), 
                 [](Handle<Value> value) -> bool {
                   return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(value);
                 },
                 [](Handle<Value> value) -> ::Windows::Networking::BackgroundTransfer::DownloadOperation^ {
                   return UnwrapDownloadOperation(value);
                 }
                );
              }
              else
              {
                return dynamic_cast<::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::DownloadOperation^>^>(NodeRT::Utils::GetObjectInstance(value));
              }
            } (args[0]);
          
          op = ::Windows::Networking::BackgroundTransfer::BackgroundDownloader::RequestUnconstrainedDownloadsAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {

            
            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapUnconstrainedTransferRequestResult(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
          
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> GetCurrentDownloadsAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ::Windows::Foundation::IAsyncOperation<::Windows::Foundation::Collections::IVectorView<::Windows::Networking::BackgroundTransfer::DownloadOperation^>^>^ op;
      

      if (args.Length() == 1)
      {
        try
        {
          op = ::Windows::Networking::BackgroundTransfer::BackgroundDownloader::GetCurrentDownloadsAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 2
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          op = ::Windows::Networking::BackgroundTransfer::BackgroundDownloader::GetCurrentDownloadsAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Foundation::Collections::IVectorView<::Windows::Networking::BackgroundTransfer::DownloadOperation^>^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {

            
            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = NodeRT::Collections::VectorViewWrapper<::Windows::Networking::BackgroundTransfer::DownloadOperation^>::CreateVectorViewWrapper(result, 
            [](::Windows::Networking::BackgroundTransfer::DownloadOperation^ val) -> Handle<Value> {
              return WrapDownloadOperation(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::DownloadOperation^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Networking::BackgroundTransfer::DownloadOperation^ {
              return UnwrapDownloadOperation(value);
            }
          );
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
          
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }


    static Handle<Value> ServerCredentialGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        ::Windows::Security::Credentials::PasswordCredential^ result = wrapper->_instance->ServerCredential;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Security.Credentials", "PasswordCredential", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ServerCredentialSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Security::Credentials::PasswordCredential^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return;
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        
        ::Windows::Security::Credentials::PasswordCredential^ winRtValue = dynamic_cast<::Windows::Security::Credentials::PasswordCredential^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->ServerCredential = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ProxyCredentialGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        ::Windows::Security::Credentials::PasswordCredential^ result = wrapper->_instance->ProxyCredential;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Security.Credentials", "PasswordCredential", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ProxyCredentialSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Security::Credentials::PasswordCredential^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return;
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        
        ::Windows::Security::Credentials::PasswordCredential^ winRtValue = dynamic_cast<::Windows::Security::Credentials::PasswordCredential^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->ProxyCredential = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MethodGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Method;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void MethodSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return;
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Method = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> GroupGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Group;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void GroupSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return;
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Group = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> CostPolicyGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy result = wrapper->_instance->CostPolicy;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CostPolicySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return;
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy winRtValue = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy>(value->Int32Value());

        wrapper->_instance->CostPolicy = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> TransferGroupGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ result = wrapper->_instance->TransferGroup;
        return scope.Close(WrapBackgroundTransferGroup(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void TransferGroupSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return;
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ winRtValue = dynamic_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->TransferGroup = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> SuccessToastNotificationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        ::Windows::UI::Notifications::ToastNotification^ result = wrapper->_instance->SuccessToastNotification;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.UI.Notifications", "ToastNotification", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void SuccessToastNotificationSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::UI::Notifications::ToastNotification^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return;
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        
        ::Windows::UI::Notifications::ToastNotification^ winRtValue = dynamic_cast<::Windows::UI::Notifications::ToastNotification^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->SuccessToastNotification = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> SuccessTileNotificationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        ::Windows::UI::Notifications::TileNotification^ result = wrapper->_instance->SuccessTileNotification;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.UI.Notifications", "TileNotification", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void SuccessTileNotificationSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::UI::Notifications::TileNotification^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return;
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        
        ::Windows::UI::Notifications::TileNotification^ winRtValue = dynamic_cast<::Windows::UI::Notifications::TileNotification^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->SuccessTileNotification = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FailureToastNotificationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        ::Windows::UI::Notifications::ToastNotification^ result = wrapper->_instance->FailureToastNotification;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.UI.Notifications", "ToastNotification", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void FailureToastNotificationSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::UI::Notifications::ToastNotification^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return;
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        
        ::Windows::UI::Notifications::ToastNotification^ winRtValue = dynamic_cast<::Windows::UI::Notifications::ToastNotification^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->FailureToastNotification = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FailureTileNotificationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        ::Windows::UI::Notifications::TileNotification^ result = wrapper->_instance->FailureTileNotification;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.UI.Notifications", "TileNotification", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void FailureTileNotificationSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::UI::Notifications::TileNotification^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundDownloader^>(info.This()))
      {
        return;
      }

      BackgroundDownloader *wrapper = BackgroundDownloader::Unwrap<BackgroundDownloader>(info.This());

      try 
      {
        
        ::Windows::UI::Notifications::TileNotification^ winRtValue = dynamic_cast<::Windows::UI::Notifications::TileNotification^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->FailureTileNotification = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Networking::BackgroundTransfer::BackgroundDownloader^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapBackgroundDownloader(::Windows::Networking::BackgroundTransfer::BackgroundDownloader^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::BackgroundDownloader^ UnwrapBackgroundDownloader(Handle<Value> value);
    friend bool IsBackgroundDownloaderWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> BackgroundDownloader::s_constructorTemplate;

  v8::Handle<v8::Value> WrapBackgroundDownloader(::Windows::Networking::BackgroundTransfer::BackgroundDownloader^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(BackgroundDownloader::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::BackgroundDownloader^ UnwrapBackgroundDownloader(Handle<Value> value)
  {
     return BackgroundDownloader::Unwrap<BackgroundDownloader>(value.As<Object>())->_instance;
  }

  void InitBackgroundDownloader(Handle<Object> exports)
  {
    BackgroundDownloader::Init(exports);
  }

  class BackgroundUploader : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("BackgroundUploader"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createUpload"), FunctionTemplate::New(CreateUpload)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setRequestHeader"), FunctionTemplate::New(SetRequestHeader)->GetFunction());
      
            
      func = FunctionTemplate::New(CreateUploadFromStreamAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createUploadFromStreamAsync"), func);
      func = FunctionTemplate::New(CreateUploadAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createUploadAsync"), func);
      
                  
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("serverCredential"), ServerCredentialGetter, ServerCredentialSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("proxyCredential"), ProxyCredentialGetter, ProxyCredentialSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("method"), MethodGetter, MethodSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("group"), GroupGetter, GroupSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("costPolicy"), CostPolicyGetter, CostPolicySetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("transferGroup"), TransferGroupGetter, TransferGroupSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("successToastNotification"), SuccessToastNotificationGetter, SuccessToastNotificationSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("successTileNotification"), SuccessTileNotificationGetter, SuccessTileNotificationSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("failureToastNotification"), FailureToastNotificationGetter, FailureToastNotificationSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("failureTileNotification"), FailureTileNotificationGetter, FailureTileNotificationSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      func = FunctionTemplate::New(GetCurrentUploadsForTransferGroupAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      constructor->Set(String::NewSymbol("getCurrentUploadsForTransferGroupAsync"), func);
      func = FunctionTemplate::New(RequestUnconstrainedUploadsAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      constructor->Set(String::NewSymbol("requestUnconstrainedUploadsAsync"), func);
      func = FunctionTemplate::New(GetCurrentUploadsAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      constructor->Set(String::NewSymbol("getCurrentUploadsAsync"), func);

      exports->Set(String::NewSymbol("BackgroundUploader"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    BackgroundUploader(::Windows::Networking::BackgroundTransfer::BackgroundUploader^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::BackgroundUploader^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::BackgroundUploader^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::Networking::BackgroundTransfer::BackgroundUploader();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      BackgroundUploader *wrapperInstance = new BackgroundUploader(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> CreateUploadFromStreamAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Networking::BackgroundTransfer::UploadOperation^>^ op;
    

      if (args.Length() == 3
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::Streams::IInputStream^>(args[1]))
      {
        try
        {
          ::Windows::Foundation::Uri^ arg0 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[0]));
          ::Windows::Storage::Streams::IInputStream^ arg1 = dynamic_cast<::Windows::Storage::Streams::IInputStream^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          op = wrapper->_instance->CreateUploadFromStreamAsync(arg0,arg1);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::BackgroundTransfer::UploadOperation^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapUploadOperation(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateUploadAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Networking::BackgroundTransfer::UploadOperation^>^ op;
    

      if (args.Length() == 3
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[0])
        && (NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^>(args[1]) || args[1]->IsArray()))
      {
        try
        {
          ::Windows::Foundation::Uri^ arg0 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[0]));
          ::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^ arg1 = 
            [] (v8::Handle<v8::Value> value) -> ::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^
            {
              if (value->IsArray())
              {
                return NodeRT::Collections::JsArrayToWinrtVector<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>(value.As<Array>(), 
                 [](Handle<Value> value) -> bool {
                   return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>(value);
                 },
                 [](Handle<Value> value) -> ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ {
                   return UnwrapBackgroundTransferContentPart(value);
                 }
                );
              }
              else
              {
                return dynamic_cast<::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^>(NodeRT::Utils::GetObjectInstance(value));
              }
            } (args[1]);
          
          op = wrapper->_instance->CreateUploadAsync(arg0,arg1);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 4
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[0])
        && (NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^>(args[1]) || args[1]->IsArray())
        && args[2]->IsString())
      {
        try
        {
          ::Windows::Foundation::Uri^ arg0 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[0]));
          ::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^ arg1 = 
            [] (v8::Handle<v8::Value> value) -> ::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^
            {
              if (value->IsArray())
              {
                return NodeRT::Collections::JsArrayToWinrtVector<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>(value.As<Array>(), 
                 [](Handle<Value> value) -> bool {
                   return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>(value);
                 },
                 [](Handle<Value> value) -> ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ {
                   return UnwrapBackgroundTransferContentPart(value);
                 }
                );
              }
              else
              {
                return dynamic_cast<::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^>(NodeRT::Utils::GetObjectInstance(value));
              }
            } (args[1]);
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          
          op = wrapper->_instance->CreateUploadAsync(arg0,arg1,arg2);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 5
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[0])
        && (NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^>(args[1]) || args[1]->IsArray())
        && args[2]->IsString()
        && args[3]->IsString())
      {
        try
        {
          ::Windows::Foundation::Uri^ arg0 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[0]));
          ::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^ arg1 = 
            [] (v8::Handle<v8::Value> value) -> ::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^
            {
              if (value->IsArray())
              {
                return NodeRT::Collections::JsArrayToWinrtVector<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>(value.As<Array>(), 
                 [](Handle<Value> value) -> bool {
                   return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>(value);
                 },
                 [](Handle<Value> value) -> ::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^ {
                   return UnwrapBackgroundTransferContentPart(value);
                 }
                );
              }
              else
              {
                return dynamic_cast<::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::BackgroundTransferContentPart^>^>(NodeRT::Utils::GetObjectInstance(value));
              }
            } (args[1]);
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          Platform::String^ arg3 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[3])));
          
          op = wrapper->_instance->CreateUploadAsync(arg0,arg1,arg2,arg3);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::BackgroundTransfer::UploadOperation^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapUploadOperation(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> CreateUpload(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::IStorageFile^>(args[1]))
      {
        try
        {
          ::Windows::Foundation::Uri^ arg0 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[0]));
          ::Windows::Storage::IStorageFile^ arg1 = dynamic_cast<::Windows::Storage::IStorageFile^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Networking::BackgroundTransfer::UploadOperation^ result;
          result = wrapper->_instance->CreateUpload(arg0, arg1);
          return scope.Close(WrapUploadOperation(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetRequestHeader(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->SetRequestHeader(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> GetCurrentUploadsForTransferGroupAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ::Windows::Foundation::IAsyncOperation<::Windows::Foundation::Collections::IVectorView<::Windows::Networking::BackgroundTransfer::UploadOperation^>^>^ op;
      

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^>(args[0]))
      {
        try
        {
          ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ arg0 = UnwrapBackgroundTransferGroup(args[0]);
          
          op = ::Windows::Networking::BackgroundTransfer::BackgroundUploader::GetCurrentUploadsForTransferGroupAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Foundation::Collections::IVectorView<::Windows::Networking::BackgroundTransfer::UploadOperation^>^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {

            
            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = NodeRT::Collections::VectorViewWrapper<::Windows::Networking::BackgroundTransfer::UploadOperation^>::CreateVectorViewWrapper(result, 
            [](::Windows::Networking::BackgroundTransfer::UploadOperation^ val) -> Handle<Value> {
              return WrapUploadOperation(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Networking::BackgroundTransfer::UploadOperation^ {
              return UnwrapUploadOperation(value);
            }
          );
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
          
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> RequestUnconstrainedUploadsAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ::Windows::Foundation::IAsyncOperation<::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^>^ op;
      

      if (args.Length() == 2
        && (NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::UploadOperation^>^>(args[0]) || args[0]->IsArray()))
      {
        try
        {
          ::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::UploadOperation^>^ arg0 = 
            [] (v8::Handle<v8::Value> value) -> ::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::UploadOperation^>^
            {
              if (value->IsArray())
              {
                return NodeRT::Collections::JsArrayToWinrtVector<::Windows::Networking::BackgroundTransfer::UploadOperation^>(value.As<Array>(), 
                 [](Handle<Value> value) -> bool {
                   return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(value);
                 },
                 [](Handle<Value> value) -> ::Windows::Networking::BackgroundTransfer::UploadOperation^ {
                   return UnwrapUploadOperation(value);
                 }
                );
              }
              else
              {
                return dynamic_cast<::Windows::Foundation::Collections::IIterable<::Windows::Networking::BackgroundTransfer::UploadOperation^>^>(NodeRT::Utils::GetObjectInstance(value));
              }
            } (args[0]);
          
          op = ::Windows::Networking::BackgroundTransfer::BackgroundUploader::RequestUnconstrainedUploadsAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Networking::BackgroundTransfer::UnconstrainedTransferRequestResult^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {

            
            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapUnconstrainedTransferRequestResult(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
          
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> GetCurrentUploadsAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ::Windows::Foundation::IAsyncOperation<::Windows::Foundation::Collections::IVectorView<::Windows::Networking::BackgroundTransfer::UploadOperation^>^>^ op;
      

      if (args.Length() == 1)
      {
        try
        {
          op = ::Windows::Networking::BackgroundTransfer::BackgroundUploader::GetCurrentUploadsAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 2
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          op = ::Windows::Networking::BackgroundTransfer::BackgroundUploader::GetCurrentUploadsAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Foundation::Collections::IVectorView<::Windows::Networking::BackgroundTransfer::UploadOperation^>^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {

            
            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = NodeRT::Collections::VectorViewWrapper<::Windows::Networking::BackgroundTransfer::UploadOperation^>::CreateVectorViewWrapper(result, 
            [](::Windows::Networking::BackgroundTransfer::UploadOperation^ val) -> Handle<Value> {
              return WrapUploadOperation(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::UploadOperation^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Networking::BackgroundTransfer::UploadOperation^ {
              return UnwrapUploadOperation(value);
            }
          );
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
          
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }


    static Handle<Value> ServerCredentialGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        ::Windows::Security::Credentials::PasswordCredential^ result = wrapper->_instance->ServerCredential;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Security.Credentials", "PasswordCredential", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ServerCredentialSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Security::Credentials::PasswordCredential^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return;
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        
        ::Windows::Security::Credentials::PasswordCredential^ winRtValue = dynamic_cast<::Windows::Security::Credentials::PasswordCredential^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->ServerCredential = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ProxyCredentialGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        ::Windows::Security::Credentials::PasswordCredential^ result = wrapper->_instance->ProxyCredential;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Security.Credentials", "PasswordCredential", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ProxyCredentialSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Security::Credentials::PasswordCredential^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return;
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        
        ::Windows::Security::Credentials::PasswordCredential^ winRtValue = dynamic_cast<::Windows::Security::Credentials::PasswordCredential^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->ProxyCredential = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MethodGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Method;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void MethodSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return;
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Method = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> GroupGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Group;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void GroupSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return;
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Group = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> CostPolicyGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy result = wrapper->_instance->CostPolicy;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CostPolicySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return;
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy winRtValue = static_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferCostPolicy>(value->Int32Value());

        wrapper->_instance->CostPolicy = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> TransferGroupGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ result = wrapper->_instance->TransferGroup;
        return scope.Close(WrapBackgroundTransferGroup(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void TransferGroupSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return;
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        
        ::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^ winRtValue = dynamic_cast<::Windows::Networking::BackgroundTransfer::BackgroundTransferGroup^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->TransferGroup = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> SuccessToastNotificationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        ::Windows::UI::Notifications::ToastNotification^ result = wrapper->_instance->SuccessToastNotification;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.UI.Notifications", "ToastNotification", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void SuccessToastNotificationSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::UI::Notifications::ToastNotification^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return;
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        
        ::Windows::UI::Notifications::ToastNotification^ winRtValue = dynamic_cast<::Windows::UI::Notifications::ToastNotification^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->SuccessToastNotification = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> SuccessTileNotificationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        ::Windows::UI::Notifications::TileNotification^ result = wrapper->_instance->SuccessTileNotification;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.UI.Notifications", "TileNotification", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void SuccessTileNotificationSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::UI::Notifications::TileNotification^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return;
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        
        ::Windows::UI::Notifications::TileNotification^ winRtValue = dynamic_cast<::Windows::UI::Notifications::TileNotification^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->SuccessTileNotification = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FailureToastNotificationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        ::Windows::UI::Notifications::ToastNotification^ result = wrapper->_instance->FailureToastNotification;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.UI.Notifications", "ToastNotification", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void FailureToastNotificationSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::UI::Notifications::ToastNotification^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return;
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        
        ::Windows::UI::Notifications::ToastNotification^ winRtValue = dynamic_cast<::Windows::UI::Notifications::ToastNotification^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->FailureToastNotification = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FailureTileNotificationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        ::Windows::UI::Notifications::TileNotification^ result = wrapper->_instance->FailureTileNotification;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.UI.Notifications", "TileNotification", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void FailureTileNotificationSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::UI::Notifications::TileNotification^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundUploader^>(info.This()))
      {
        return;
      }

      BackgroundUploader *wrapper = BackgroundUploader::Unwrap<BackgroundUploader>(info.This());

      try 
      {
        
        ::Windows::UI::Notifications::TileNotification^ winRtValue = dynamic_cast<::Windows::UI::Notifications::TileNotification^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->FailureTileNotification = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Networking::BackgroundTransfer::BackgroundUploader^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapBackgroundUploader(::Windows::Networking::BackgroundTransfer::BackgroundUploader^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::BackgroundUploader^ UnwrapBackgroundUploader(Handle<Value> value);
    friend bool IsBackgroundUploaderWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> BackgroundUploader::s_constructorTemplate;

  v8::Handle<v8::Value> WrapBackgroundUploader(::Windows::Networking::BackgroundTransfer::BackgroundUploader^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(BackgroundUploader::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::BackgroundUploader^ UnwrapBackgroundUploader(Handle<Value> value)
  {
     return BackgroundUploader::Unwrap<BackgroundUploader>(value.As<Object>())->_instance;
  }

  void InitBackgroundUploader(Handle<Object> exports)
  {
    BackgroundUploader::Init(exports);
  }

  class BackgroundTransferError : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("BackgroundTransferError"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("getStatus"), FunctionTemplate::New(GetStatus)->GetFunction());

      exports->Set(String::NewSymbol("BackgroundTransferError"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    BackgroundTransferError(::Windows::Networking::BackgroundTransfer::BackgroundTransferError^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::BackgroundTransferError^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::BackgroundTransferError^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::BackgroundTransferError^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      BackgroundTransferError *wrapperInstance = new BackgroundTransferError(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  


    static Handle<Value> GetStatus(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && args[0]->IsInt32())
      {
        try
        {
          int arg0 = static_cast<int>(args[0]->Int32Value());
          
          ::Windows::Web::WebErrorStatus result;
          result = ::Windows::Networking::BackgroundTransfer::BackgroundTransferError::GetStatus(arg0);
          return scope.Close(Integer::New(static_cast<int>(result)));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



  private:
    ::Windows::Networking::BackgroundTransfer::BackgroundTransferError^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapBackgroundTransferError(::Windows::Networking::BackgroundTransfer::BackgroundTransferError^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::BackgroundTransferError^ UnwrapBackgroundTransferError(Handle<Value> value);
    friend bool IsBackgroundTransferErrorWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> BackgroundTransferError::s_constructorTemplate;

  v8::Handle<v8::Value> WrapBackgroundTransferError(::Windows::Networking::BackgroundTransfer::BackgroundTransferError^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(BackgroundTransferError::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::BackgroundTransferError^ UnwrapBackgroundTransferError(Handle<Value> value)
  {
     return BackgroundTransferError::Unwrap<BackgroundTransferError>(value.As<Object>())->_instance;
  }

  void InitBackgroundTransferError(Handle<Object> exports)
  {
    BackgroundTransferError::Init(exports);
  }

  class ContentPrefetcher : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ContentPrefetcher"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->SetAccessor(String::NewSymbol("lastSuccessfulPrefetchTime"), LastSuccessfulPrefetchTimeGetter);
      constructor->SetAccessor(String::NewSymbol("indirectContentUri"), IndirectContentUriGetter, IndirectContentUriSetter);
      constructor->SetAccessor(String::NewSymbol("contentUris"), ContentUrisGetter);

      exports->Set(String::NewSymbol("ContentPrefetcher"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ContentPrefetcher(::Windows::Networking::BackgroundTransfer::ContentPrefetcher^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Networking::BackgroundTransfer::ContentPrefetcher^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Networking::BackgroundTransfer::ContentPrefetcher^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Networking::BackgroundTransfer::ContentPrefetcher^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ContentPrefetcher *wrapperInstance = new ContentPrefetcher(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  




    static Handle<Value> LastSuccessfulPrefetchTimeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        ::Platform::IBox<::Windows::Foundation::DateTime>^ result = ::Windows::Networking::BackgroundTransfer::ContentPrefetcher::LastSuccessfulPrefetchTime;
        return scope.Close(result ? NodeRT::Utils::DateTimeToJS(result->Value): static_cast<Handle<Value>>(Undefined()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> IndirectContentUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        ::Windows::Foundation::Uri^ result = ::Windows::Networking::BackgroundTransfer::ContentPrefetcher::IndirectContentUri;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "Uri", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void IndirectContentUriSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      try 
      {

        
        ::Windows::Foundation::Uri^ winRtValue = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(value));

        ::Windows::Networking::BackgroundTransfer::ContentPrefetcher::IndirectContentUri = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ContentUrisGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;

      try 
      {
        ::Windows::Foundation::Collections::IVector<::Windows::Foundation::Uri^>^ result = ::Windows::Networking::BackgroundTransfer::ContentPrefetcher::ContentUris;
        return scope.Close(NodeRT::Collections::VectorWrapper<::Windows::Foundation::Uri^>::CreateVectorWrapper(result, 
            [](::Windows::Foundation::Uri^ val) -> Handle<Value> {
              return NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "Uri", val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Foundation::Uri^ {
              return dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(value));
            }
          ));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    

  private:
    ::Windows::Networking::BackgroundTransfer::ContentPrefetcher^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapContentPrefetcher(::Windows::Networking::BackgroundTransfer::ContentPrefetcher^ wintRtInstance);
    friend ::Windows::Networking::BackgroundTransfer::ContentPrefetcher^ UnwrapContentPrefetcher(Handle<Value> value);
    friend bool IsContentPrefetcherWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ContentPrefetcher::s_constructorTemplate;

  v8::Handle<v8::Value> WrapContentPrefetcher(::Windows::Networking::BackgroundTransfer::ContentPrefetcher^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ContentPrefetcher::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Networking::BackgroundTransfer::ContentPrefetcher^ UnwrapContentPrefetcher(Handle<Value> value)
  {
     return ContentPrefetcher::Unwrap<ContentPrefetcher>(value.As<Object>())->_instance;
  }

  void InitContentPrefetcher(Handle<Object> exports)
  {
    ContentPrefetcher::Init(exports);
  }

} } } } 

void init(Handle<Object> exports)
{
  if (FAILED(CoInitializeEx(nullptr, COINIT_MULTITHREADED)))
  {
    ThrowException(v8::Exception::Error(NodeRT::Utils::NewString(L"error in CoInitializeEx()")));
    return;
  }
  
  NodeRT::Windows::Networking::BackgroundTransfer::InitBackgroundTransferStatusEnum(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitBackgroundTransferCostPolicyEnum(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitBackgroundTransferPriorityEnum(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitBackgroundTransferBehaviorEnum(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitIBackgroundTransferBase(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitDownloadOperation(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitUnconstrainedTransferRequestResult(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitUploadOperation(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitBackgroundTransferGroup(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitBackgroundTransferContentPart(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitIBackgroundTransferOperation(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitResponseInformation(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitIBackgroundTransferOperationPriority(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitIBackgroundTransferContentPartFactory(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitBackgroundDownloader(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitBackgroundUploader(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitBackgroundTransferError(exports);
  NodeRT::Windows::Networking::BackgroundTransfer::InitContentPrefetcher(exports);

  NodeRT::Utils::RegisterNameSpace("Windows.Networking.BackgroundTransfer", exports);
}


NODE_MODULE(binding, init)